Coverage for vcr.serializers.jsonserializer: 64%

# Coverage for vcr.serializers.jsonserializer : 64%

## 11 statements 7 run 4 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 | try: import simplejson as json except ImportError: import json def deserialize(cassette_string): return json.loads(cassette_string) def serialize(cassette_dict): try: return json.dumps(cassette_dict, indent=4) except UnicodeDecodeError as original: raise UnicodeDecodeError( original.encoding, b"Error serializing cassette to JSON", original.start, original.end, original.args[-1] + ("Does this HTTP interaction contain binary data? " "If so, use a different serializer (like the yaml serializer) " "for this request?") )